@@ -58,23 +58,19 @@ report_table.character <- function(x,
   table_full$percentage_Missing <- table_full$n_Missing / table_full$n_Obs * 100
   table <- table_full
 
-  if (missing_percentage == TRUE) {
+  if (isTRUE(missing_percentage)) {
     table <- datawizard::data_remove(table, "n_Missing")
   } else {
     table <- datawizard::data_remove(table, "percentage_Missing")
   }
 
-
   as.report_table(table_full, summary = table, entries = n_char)
 }
 
 
 
-
 # report_parameters -------------------------------------------------------
 
-
-
 #' @export
 report_parameters.character <- function(x,
                                         table = NULL,
@@ -96,7 +92,7 @@ report_parameters.character <- function(x,
   }
   entries <- attributes(table)$entries
 
-  if (levels_percentage == TRUE) {
+  if (levels_percentage) {
     text <- paste0(entries$Entry, " (", insight::format_value(entries$percentage_Entry, as_percent = TRUE), ")")
   } else {
     text <- paste0(entries$Entry, " (n = ", entries$n_Entry, ")")
@@ -162,7 +158,7 @@ report_text.character <- function(x,
   # Missing
   text_n_Missing <- paste0(table$n_Missing[1], " missing")
   text_percentage_Missing <- paste0(insight::format_value(table$percentage_Missing[1]), "% missing")
-  if (missing_percentage == TRUE) {
+  if (isTRUE(missing_percentage)) {
     text_full <- paste0(text_full, "(", text_percentage_Missing, ")")
     if (table$n_Missing[1] > 0) {
       text <- paste0(text, " (", text_percentage_Missing, ")")
@@ -203,7 +199,7 @@ report_statistics.character <- function(x,
   }
   entries <- attributes(table)$entries
 
-  if (levels_percentage == TRUE) {
+  if (levels_percentage) {
     text <- paste0(entries$Entry, ", ", insight::format_value(entries$percentage_Entry, as_percent = TRUE), "%")
   } else {
     text <- paste0(entries$Entry, ", n = ", entries$n_Entry)
